.. _examples-index:

####################
HyperSpy Examples
####################

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    data_navigation/index.rst

    hyperspy_as_library/index.rst

    model_fitting/index.rst

    simple_simulations/index.rst

